@@ -8,9 +8,9 @@ from .base_adapter import BaseAdapter
 class AdaBN(BaseAdapter):
     hook_cls = AdaBNHook
 
-    def __init__(self, inference_fn=None, **kwargs):
+    def __init__(self, *args, inference_fn=None, **kwargs):
         inference_fn = c_f.default(inference_fn, adabn_fn)
-        super().__init__(inference_fn=inference_fn, **kwargs)
+        super().__init__(*args, inference_fn=inference_fn, **kwargs)
 
     def init_hook(self, hook_kwargs):
         self.hook = self.hook_cls(**hook_kwargs)
